Job

Struct Job 

pub struct Job<D = ()> {
    pub job_id: String,
    pub execution_resource_id: String,
    pub guard_scope: ExecutionGuardScope,
    pub schedule: Schedule,
    pub time_window: Option<JobTimeWindow>,
    pub max_runs: Option<u32>,
    pub missed_run_policy: MissedRunPolicy,
    pub overlap_policy: OverlapPolicy,
    /* private fields */
}

Fields

job_id: Stringexecution_resource_id: Stringguard_scope: ExecutionGuardScopeschedule: Scheduletime_window: Option<JobTimeWindow>max_runs: Option<u32>missed_run_policy: MissedRunPolicyoverlap_policy: OverlapPolicy

Implementations

Source

impl Job<()>

pub fn without_deps( job_id: impl Into<String>, schedule: Schedule, task: Task<()>, ) -> Self

Create a job that uses no injected dependencies.

Source

impl<D> Job<D>
where D: Send + Sync + 'static,

pub fn new( job_id: impl Into<String>, schedule: Schedule, deps: impl Into<Arc<D>>, task: Task<D>, ) -> Self

Create a job from explicit dependencies and a task handler.

Source

impl<D> Job<D>

pub fn with_max_runs(self, max_runs: u32) -> Self

Limit how many triggers this job can consume before it exits.

This applies to Schedule::Interval, Schedule::AtTimes, and Schedule::Cron. A value of 0 makes the job exit immediately without running.

pub fn with_missed_run_policy(self, policy: MissedRunPolicy) -> Self

pub fn with_overlap_policy(self, policy: OverlapPolicy) -> Self

pub fn with_time_window(self, time_window: JobTimeWindow) -> Self

pub fn with_execution_resource_id(self, resource_id: impl Into<String>) -> Self

pub fn with_guard_scope(self, scope: ExecutionGuardScope) -> Self