pub struct Task<D> { /* private fields */ }Implementations
Sourceimpl<D> Task<D>
impl<D> Task<D>
Sourcepub fn from_async<F, Fut>(task: F) -> Self
pub fn from_async<F, Fut>(task: F) -> Self
Create an async task from the full TaskContext.
Sourcepub fn from_sync<F>(task: F) -> Self
pub fn from_sync<F>(task: F) -> Self
Create a lightweight synchronous task from the full TaskContext.
Sourcepub fn from_blocking<F>(task: F) -> Self
pub fn from_blocking<F>(task: F) -> Self
Create a blocking synchronous task from the full TaskContext.